CompassController class

Inheritance

Constructors

CompassController()

Properties

centerOffset double
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
heading double
getter/setter pair
itemCount int
getter/setter pair
items List<String>
getter/setter pair
itemWidth double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController
getter/setter pair
scrollOffset double
getter/setter pair
showIndex bool
final
targetHeading double
getter/setter pair
width double
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
getHeadingOffset(double currentHeading) double
initItems(double heading, double width, double itemWidth) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
scrollToHeading(double heading) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited